import 'package:flutter/material.dart';

import '../../globals.dart';
import '../../models/timeline_entry.dart';
import '../../services/entry_manager_service.dart';
import '../../utils/snackbar_builder.dart';

class InteractionsBarControl extends StatefulWidget {
  final TimelineEntry entry;
  const InteractionsBarControl({super.key, required this.entry});

  @override
  State<InteractionsBarControl> createState() => _InteractionsBarControlState();
}

class _InteractionsBarControlState extends State<InteractionsBarControl> {
  bool isFavorited = false;
  int reshares = 0;
  int comments = 0;
  int likes = 0;

  @override
  void initState() {
    super.initState();
    isFavorited = widget.entry.isFavorited;
    comments = widget.entry.engagementSummary.repliesCount;
    reshares = widget.entry.engagementSummary.rebloggedCount;
    likes = widget.entry.engagementSummary.favoritesCount;
  }

  Future<void> toggleFavorited() async {
    final newState = !isFavorited;
    print('Trying to toggle favorite from $isFavorited to $newState');
    final result = await getIt<EntryManagerService>()
        .toggleFavorited(widget.entry.id, newState);
    result.match(onSuccess: (update) {
      setState(() {
        print('Success toggling! $isFavorited -> ${update.entry.isFavorited}');
        isFavorited = update.entry.isFavorited;
      });
    }, onError: (error) {
      buildSnackbar(context, 'Error toggling like status: $error');
    });
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text('$likes likes, $reshares reshares, $comments comments'),
        IconButton(
            onPressed: toggleFavorited,
            icon: isFavorited
                ? Icon(Icons.thumb_up)
                : Icon(Icons.thumb_up_outlined)),
      ],
    );
  }
}
